CarouselListViewController class

Controlla il carousel_listview, ne gestisce lo scroll e il widget visualizzato

Constructors

CarouselListViewController(BuildContext context, {dynamic onElementChange(int)?, required ScrollController scrollController, required int numOfChildren, required bool infiniteScroll, Duration? scrollDuration, required int currentIndex})

Properties

currentIndex int
Index corrente dell'elemento da mostrare
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
infiniteScroll bool
Abilita lo scorrimento indifinito
getter/setter pair
numOfChildren int
Numero di elementi presenti nel carousel
getter/setter pair
onElementChange → dynamic Function(int)?
Funzione esterna chiamata dopo ogni scorrimento completato Necessita int come parametro in modo da poter ottenere l'index del widget che verrà mostrato
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scrollController ScrollController
final
scrollDuration Duration?
Durata dell'animazione di scroll
getter/setter pair

Methods

formatWidgets(List<Widget> children) List<CarouselListViewFullWidthCard>
Get all children in formatted specific way
HandleScroll(DragEndDetails d) → void
On drag action, invia a scroll la direzione in cui scorrere
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
scrollToIndex(int i) → void
Scorri di un elemento nella direzione determinata dallo swipe Se overflow controlla che sia disponibile lo scroll infinit
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited